.. raw :: html

    <!-- Generated by generate_authors_table.py -->
    <div class="sk-authors-container">
    <style>
      img.avatar {border-radius: 10px;}
    </style>
    <div>
    <a href='https://github.com/ArturoAmorQ'><img src='https://avatars.githubusercontent.com/u/86408019?v=4' class='avatar' /></a> <br />
    <p>Arturo Amor</p>
    </div>
    <div>
    <a href='https://github.com/alfaro96'><img src='https://avatars.githubusercontent.com/u/32649176?v=4' class='avatar' /></a> <br />
    <p>Juan Carlos Alfaro Jiménez</p>
    </div>
    <div>
    <a href='https://github.com/lucyleeow'><img src='https://avatars.githubusercontent.com/u/23182829?v=4' class='avatar' /></a> <br />
    <p>Lucy Liu</p>
    </div>
    <div>
    <a href='https://github.com/jmloyola'><img src='https://avatars.githubusercontent.com/u/2133361?v=4' class='avatar' /></a> <br />
    <p>Juan Martin Loyola</p>
    </div>
    <div>
    <a href='https://github.com/smarie'><img src='https://avatars.githubusercontent.com/u/3236794?v=4' class='avatar' /></a> <br />
    <p>Sylvain Marié</p>
    </div>
    <div>
    <a href='https://github.com/cmarmo'><img src='https://avatars.githubusercontent.com/u/1662261?v=4' class='avatar' /></a> <br />
    <p>Chiara Marmo</p>
    </div>
    <div>
    <a href='https://github.com/MaxwellLZH'><img src='https://avatars.githubusercontent.com/u/16646940?v=4' class='avatar' /></a> <br />
    <p>Maxwell Liu</p>
    </div>
    <div>
    <a href='https://github.com/norbusan'><img src='https://avatars.githubusercontent.com/u/1735589?v=4' class='avatar' /></a> <br />
    <p>Norbert Preining</p>
    </div>
    <div>
    <a href='https://github.com/reshamas'><img src='https://avatars.githubusercontent.com/u/2507232?v=4' class='avatar' /></a> <br />
    <p>Reshama Shaikh</p>
    </div>
    <div>
    <a href='https://github.com/albertcthomas'><img src='https://avatars.githubusercontent.com/u/15966638?v=4' class='avatar' /></a> <br />
    <p>Albert Thomas</p>
    </div>
    </div>
